# Week 3 Homework

## Q&A

1. SJF와 FIFO 스케줄러로 길이가 200인 세 개의 작업을 실행할 때의 응답 시간과 반환 시간을 계산하세요.
   A:
   SJF
   |작업|응답 시간|처리 시간|
   | 작업 0 | 0 | 200 |
   | 직업 1 | 200 | 400 |
   | 작업 2 | 400 | 600 |
   FIFO
   |작업|응답 시간|처리 시간|
   | 작업 0 | 0 | 200 |
   | 작업 1 | 200 | 400 |
   | 작업 2 | 400 | 600 |

2. 이제 작업의 길이를 다르게 하여 동일한 작업을 수행해 보세요: 100, 200, 300.
   A: SJF
   |작업|응답 시간|처리 시간|
   | 작업 0 | 0 | 100 |
   | 직업 1 | 100 | 300 |
   | 작업 2 | 300 | 600 |
   FIFO
   |작업|응답 시간|처리 시간|
   | 작업 0 | 0 | 100 |
   | 작업 1 | 100 | 300 |
   | 작업 2 | 300 | 600 |

3. 이제 RR 스케줄러와 시간 할당량(time-slice)을 1로 하여 동일한 작업을 수행해 보세요.
   A:
   |작업|RR|
   | 1 | 1 |
   | 2 | 2 |
   | 3 | 3 |

4. 어떤 유형의 워크로드에 대해 SJF가 FIFO와 동일한 반환 시간을 제공하나요?
   A: 모든 작업의 길이가 동일한 경우 제공한다.

5. 어떤 유형의 워크로드와 시간 할당량에 대해 SJF가 RR과 동일한 응답 시간을 제공하나요?
   A: 모든 작업의 길이가 서로 크게 다르고, 시간 할당량이 충분히 큰 경우에 제공한다.

6. 작업 길이가 증가함에 따라 SJF에서 응답 시간은 어떻게 되나요?
   A: 감소한다.
   시뮬레이터를 사용하여 이 추세를 보여줄 수 있나요?
   A: 보여줄 수 있다.

7. 시간 할당량이 증가함에 따라 RR에서 응답 시간은 어떻게 되나요?
   A: 감소한다.
   N개의 작업이 주어졌을 때 최악의 응답 시간을 제공하는 수식을 작성할 수 있나요?
   A: (N-1)\*quantum
